==> open5gs_2.5.4.202211030053.tar.xz: BUILD/lib/pfcp/support/cache/tlv-msg-6.py <==
ies = []
ies.append({ "ie_type" : "Node ID", "ie_value" : "Node ID", "presence" : "M", "tlv_more" : "0", "comment" : "This IE shall contain the unique identifier of the sending Node."})
ies.append({ "ie_type" : "Cause", "ie_value" : "Cause", "presence" : "M", "tlv_more" : "0", "comment" : "This IE shall indicate the acceptance or the rejection of the corresponding request message."})
ies.append({ "ie_type" : "Recovery Time Stamp", "ie_value" : "Recovery Time Stamp", "presence" : "M", "tlv_more" : "0", "comment" : "This IE shall contain the time stamp when the CP or UP function was started, see clause19A of 3GPPTS23.007[24]. (NOTE)"})
ies.append({ "ie_type" : "UP Function Features", "ie_value" : "UP Function Features", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the UP function sends this message and the UP function supports at least one UP feature defined in this IE.When present, this IE shall indicate the features the UP function supports."})
ies.append({ "ie_type" : "CP Function Features", "ie_value" : "CP Function Features", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the CP function sends this message and the CP function supports at least one CP feature defined in this IE.When present, this IE indicates the features the CP function supports."})
ies.append({ "ie_type" : "User Plane IP Resource Information", "ie_value" : "User Plane IP Resource Information", "presence" : "O", "tlv_more" : "3", "comment" : "This IE may be present if the UP function sends this message.When present, this IE shall contain an IPv4 and/or an IPv6 address, together with a TEID range that the CP function shall use to allocate GTP-U F-TEID in the UP function.Several IEs with the same IE type may be present to represent multiple User Plane IP Resources."})
ies.append({ "ie_type" : "Alternative SMF IP Address", "ie_value" : "Alternative SMF IP Address", "presence" : "O", "tlv_more" : "0", "comment" : "This IE may be present if the SMF advertises the support of the SSET and/or MPAS feature in the CP Function Features IE (see clause8.2.58).When present, this IE shall contain an IPv4 and/or IPv6 address of an alternative SMF or an alternative PFCP entity in the same SMF when SSET feature is used, or an alternative PFCP entity in the same SMF when MPAS feature is used.Several IEs with the same IE type may be present to represent multiple alternative SMF IP addresses."})
ies.append({ "ie_type" : "SMF Set ID", "ie_value" : "SMF Set ID", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the CP function sends this message and SMF advertises the support of the MPAS feature in the CP Function Features IE (see clause5.22.3).When present, this IE shall contain an FQDN representing the SMF set to which the SMF belongs."})
ies.append({ "ie_type" : "PFCPASRsp-Flags", "ie_value" : "PFCPASRsp-Flags", "presence" : "O", "tlv_more" : "0", "comment" : "This IE shall be included if at least one of the flags is set to 1:-	PSREI (PFCP Session Retained Indication): the UP function shall set this flag to 1 if the PFCP Session Retention Information IE was received in the Request, an existing PFCP association was already established for the same Node ID and the requested PFCP sessions have been retained. See clause6.2.6.2.2.-	UUPSI (UPF configured for IPUPS): the UP function shall set this flag to 1 if the UPF is configured to be used for IPUPS. See clause5.27."})
ies.append({ "ie_type" : "Clock Drift Control Information", "ie_value" : "Clock Drift Control Information", "presence" : "C", "tlv_more" : "0", "comment" : "his IE may be present, if the CP function sends this message, to request the UPF to report clock drift between the TSN time and 5GS time for TSN working domains (see clause5.26.4).Several IEs with the same IE type may be present to represent multiple TSN time domains (with different parameters).See Table7.4.4.1.2-1."})
ies.append({ "ie_type" : "UE IP Address", "ie_value" : "UE IP address Pool Information", "presence" : "O", "tlv_more" : "0", "comment" : "This IE may be present when the UP function sends this message, if UE IP Address Pools are configured in the UP function.Several IE with the same IE type may be present to represent multiple UE IP address Pool Information.The IE shall be encoded as in Table 7.4.4.1-3. "})
ies.append({ "ie_type" : "GTP-U Path QoS Control Information", "ie_value" : "GTP-U Path QoS Control Information", "presence" : "C", "tlv_more" : "0", "comment" : "This IE may be present, if the CP function sends this message, to request the UPF to monitor the QoS on GTP-U paths (see clause5.24.5).Several IEs with the same IE type may be present to represent multiple GTP-U paths to monitor.See Table7.4.4.1.3-1."})
ies.append({ "ie_type" : "NF Instance ID", "ie_value" : "UPF Instance ID", "presence" : "O", "tlv_more" : "0", "comment" : "This IE may be present if the UP function is a 5G UPF and if available, and if the message is sent by the UPF."})
msg_list[key]["ies"] = ies

==> open5gs_2.6.2.tar.xz: BUILD/lib/pfcp/support/cache/tlv-msg-6.py <==
ies = []
ies.append({ "ie_type" : "Node ID", "ie_value" : "Node ID", "presence" : "M", "tlv_more" : "0", "comment" : "This IE shall contain the unique identifier of the sending Node."})
ies.append({ "ie_type" : "Cause", "ie_value" : "Cause", "presence" : "M", "tlv_more" : "0", "comment" : "This IE shall indicate the acceptance or the rejection of the corresponding request message."})
ies.append({ "ie_type" : "Recovery Time Stamp", "ie_value" : "Recovery Time Stamp", "presence" : "M", "tlv_more" : "0", "comment" : "This IE shall contain the time stamp when the CP or UP function was started, see clause19A of 3GPPTS23.007[24]. (NOTE)"})
ies.append({ "ie_type" : "UP Function Features", "ie_value" : "UP Function Features", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the UP function sends this message and the UP function supports at least one UP feature defined in this IE.When present, this IE shall indicate the features the UP function supports."})
ies.append({ "ie_type" : "CP Function Features", "ie_value" : "CP Function Features", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the CP function sends this message and the CP function supports at least one CP feature defined in this IE.When present, this IE indicates the features the CP function supports."})
ies.append({ "ie_type" : "User Plane IP Resource Information", "ie_value" : "User Plane IP Resource Information", "presence" : "O", "tlv_more" : "3", "comment" : "This IE may be present if the UP function sends this message.When present, this IE shall contain an IPv4 and/or an IPv6 address, together with a TEID range that the CP function shall use to allocate GTP-U F-TEID in the UP function.Several IEs with the same IE type may be present to represent multiple User Plane IP Resources."})
ies.append({ "ie_type" : "Alternative SMF IP Address", "ie_value" : "Alternative SMF IP Address", "presence" : "O", "tlv_more" : "0", "comment" : "This IE may be present if the (MB-)SMF advertises the support of the SSET and/or MPAS feature in the CP Function Features IE (see clause8.2.58).When present, this IE shall contain an IPv4 and/or IPv6 address of an alternative (MB-)SMF or an alternative PFCP entity in the same (MB-)SMF when SSET feature is used, or an alternative PFCP entity in the same (MB-)SMF when MPAS feature is used.Several IEs with the same IE type may be present to represent multiple alternative (MB-)SMF IP addresses."})
ies.append({ "ie_type" : "SMF Set ID", "ie_value" : "SMF Set ID", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the CP function sends this message and (MB-)SMF advertises the support of the MPAS feature in the CP Function Features IE (see clause5.22.3).When present, this IE shall contain an FQDN representing the (MB-)SMF set to which the (MB-)SMF belongs."})
ies.append({ "ie_type" : "PFCPASRsp-Flags", "ie_value" : "PFCPASRsp-Flags", "presence" : "O", "tlv_more" : "0", "comment" : "This IE shall be included if at least one of the flags is set to 1:-	PSREI (PFCP Session Retained Indication): the UP function shall set this flag to 1 if the PFCP Session Retention Information IE was received in the Request, an existing PFCP association was already established for the same Node ID and the requested PFCP sessions have been retained. See clause6.2.6.2.2.-	UUPSI (UPF configured for IPUPS): the UP function shall set this flag to 1 if the UPF is configured to be used for IPUPS. See clause5.27."})
ies.append({ "ie_type" : "Clock Drift Control Information", "ie_value" : "Clock Drift Control Information", "presence" : "C", "tlv_more" : "0", "comment" : "This IE may be present, if the CP function sends this message, to request the UPF to report clock drift between the external time and 5GS time for external working domains (see clause5.26.4).Several IEs with the same IE type may be present to represent multiple external time domains (with different parameters).See Table7.4.4.1.2-1."})
ies.append({ "ie_type" : "UE IP Address", "ie_value" : "UE IP address Pool Information", "presence" : "O", "tlv_more" : "0", "comment" : "This IE may be present when the UP function sends this message, if UE IP Address Pools are configured in the UP function.Several IE with the same IE type may be present to represent multiple UE IP address Pool Information.The IE shall be encoded as in Table 7.4.4.1-3. "})
ies.append({ "ie_type" : "GTP-U Path QoS Control Information", "ie_value" : "GTP-U Path QoS Control Information", "presence" : "C", "tlv_more" : "0", "comment" : "This IE may be present, if the CP function sends this message, to request the UPF to monitor the QoS on GTP-U paths (see clause5.24.5).Several IEs with the same IE type may be present to represent multiple GTP-U paths to monitor.See Table7.4.4.1.3-1."})
ies.append({ "ie_type" : "NF Instance ID", "ie_value" : "UPF Instance ID", "presence" : "O", "tlv_more" : "0", "comment" : "This IE may be present if the UP function is a 5G UP function and if available, and if the message is sent by the UP function."})
msg_list[key]["ies"] = ies
